@@ -75,7 +75,15 @@ class Ingo_Script_Procmail_Recipe implements Ingo_Script_Item
         if (isset($this->_params['transport'][Ingo::RULE_ALL]['params']['delivery_mailbox_prefix'])) {
             $delivery .= ' ' . $this->_params['transport'][Ingo::RULE_ALL]['params']['delivery_mailbox_prefix'];
         }
-
+        if (!empty($this->_params['transport'][Ingo::RULE_ALL]['params']['date'])) {
+            $this->_params['date'] = $this->_params['transport'][Ingo::RULE_ALL]['params']['date'];
+        }
+        if (!empty($this->_params['transport'][Ingo::RULE_ALL]['params']['echo'])) {
+            $this->_params['echo'] = $this->_params['transport'][Ingo::RULE_ALL]['params']['echo'];
+        }
+        if (!empty($this->_params['transport'][Ingo::RULE_ALL]['params']['ls'])) {
+            $this->_params['ls'] = $this->_params['transport'][Ingo::RULE_ALL]['params']['ls'];
+        }
         switch ($params['action']) {
         case Ingo_Storage::ACTION_KEEP:
             // Note: you may have to set the DEFAULT variable in your
@@ -229,6 +237,8 @@ class Ingo_Script_Procmail_Recipe implements Ingo_Script_Item
                     . ' -e "' . $reason . '" \\';
                 $this->_action[] = '      ) | $SENDMAIL -f' . $address
                     . ' -oi -t';
+                $this->_action[] = '      :0';
+                $this->_action[] = '      /dev/null';
                 $this->_action[] = '    }';
                 $this->_action[] = '  }';
             }
